@@ -15,7 +15,7 @@
 import json
 from datetime import timedelta
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from robot.utils import get_link_path  # type: ignore
 
@@ -30,6 +30,7 @@ from ..utils import (
     SelectionType,
     SupportedBrowsers,
     ViewportDimensions,
+    attribute_warning,
     convert_typed_dict,
     find_by_id,
     keyword,
@@ -337,6 +338,9 @@ class PlaywrightState(LibraryComponent):
             return response.body
 
     @keyword(tags=("Setter", "BrowserControl"))
+    @attribute_warning(
+        old_args=("videosPath", "videoSize"), new_args=("recordVideo", "recordVideo")
+    )
     def new_context(
         self,
         acceptDownloads: bool = False,
@@ -361,6 +365,7 @@ class PlaywrightState(LibraryComponent):
         videoSize: Optional[ViewportDimensions] = None,
         defaultBrowserType: Optional[SupportedBrowsers] = None,
         hideRfBrowser: bool = False,
+        recordVideo: Optional[str] = None,
     ) -> str:
         """Create a new BrowserContext with specified options.
         See `Browser, Context and Page` for more information about BrowserContext.
@@ -431,12 +436,14 @@ class PlaywrightState(LibraryComponent):
         Note that browser needs to be launched with the global proxy for this option to work.
         If all contexts override the proxy, global proxy will be never used and can be any string
 
-        ``videosPath`` Enables video recording for all pages to videosPath
+        ``videosPath`` is deprecated by playwright, use recordVideo instead.
+        Enables video recording for all pages to videosPath
         folder. If videosPath is not existing folder, videosPath folder is created
         under ${OUTPUT_DIR}/browser/video/ folder. If videosPath is not specified,
         videos are not recorded.
 
-        ``videoSize`` Specifies dimensions of the automatically recorded
+        ``videoSize`` is deprecated by playwright, use recordVideo instead.
+        Specifies dimensions of the automatically recorded
         video. Can only be used if videosPath is set. If not specified the size will
         be equal to viewport. If viewport is not configured explicitly the video size
         defaults to 1280x720. Actual picture of the page will be scaled down if
@@ -447,6 +454,17 @@ class PlaywrightState(LibraryComponent):
         with defaults, it now uses this setting.
         Very useful together with `Get Device` keyword:
 
+        ``recordVideo`` enables video recording for all pages into a folder. If not
+        specified videos are not recorded. Make sure to close context for videos to be saved.
+        ``recordVideo`` is dictionary containing `dir` and `size` keys. If `dir` is not
+        existing folder, videosPath folder is created under
+        ${OUTPUT_DIR}/browser/video/ folder. `size` Optional dimensions of the recorded
+        videos. If not specified the size will be equal to viewport. If viewport is not
+        configured explicitly the video size defaults to 1280x720. Actual picture of
+        each page will be scaled down if necessary to fit the specified size.
+        `size` is dictionary containing `width` (Video frame width) and  `height`
+        (Video frame height) keys.
+
         Example:
         | Test an iPhone
         |     ${device}=    `Get Device`    iPhone X
@@ -462,6 +480,7 @@ class PlaywrightState(LibraryComponent):
         """
         params = locals_to_params(locals())
         params = self._set_video_path(params)
+        params = self._set_video_size_to_int(params)
         params = convert_typed_dict(self.new_context.__annotations__, params)
         if not videosPath:
             params.pop("videoSize", None)
@@ -479,16 +498,37 @@ class PlaywrightState(LibraryComponent):
         self.context_cache.add(response.body, self._get_video_size(params))
         return response.body
 
-    def _set_video_path(self, params):
+    def _set_video_path(self, params: dict) -> dict:
         video_path = params.get("videosPath")
+        record_video = params.get("recordVideo", {})
+        if not video_path:
+            video_path = record_video.get("dir")
         if not video_path:
             return params
         if Path(video_path).is_dir():
             return params
-        params["videosPath"] = self.video_output / video_path
+        if record_video:
+            params["recordVideo"]["dir"] = self.video_output / video_path
+        else:
+            params["videosPath"] = self.video_output / video_path
+        return params
+
+    def _get_record_video_size(self, params) -> Tuple[Optional[int], Optional[int]]:
+        width = params.get("recordVideo", {}).get("size", {}).get("width")
+        height = params.get("recordVideo", {}).get("size", {}).get("height")
+        return int(width) if width else None, int(height) if height else None
+
+    def _set_video_size_to_int(self, params: dict) -> dict:
+        width, height = self._get_record_video_size(params)
+        if width and height:
+            params["recordVideo"]["size"]["width"] = width
+            params["recordVideo"]["size"]["height"] = height
         return params
 
     def _get_video_size(self, params: dict) -> dict:
+        width, height = self._get_record_video_size(params)
+        if width and height:
+            return {"width": width, "height": height}
         if "videoSize" in params:
             return params["videoSize"]
         if "viewport" in params:
@@ -537,10 +577,13 @@ class PlaywrightState(LibraryComponent):
         self,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
+        message: Optional[str] = None,
     ) -> Dict:
         """Returns all browsers, open contexts in them and open pages in these contexts.
         See `Browser, Context and Page` for more information about these concepts.
 
+        ``message`` overrides the default error message.
+
         The data is parsed into a python list containing data representing the open Objects.
 
         On the root level the data contains a list of open browsers.
@@ -610,7 +653,11 @@ class PlaywrightState(LibraryComponent):
             parsed = json.loads(response.json)
             logger.info(json.dumps(parsed))
             return verify_assertion(
-                parsed, assertion_operator, assertion_expected, "Browser Catalog "
+                parsed,
+                assertion_operator,
+                assertion_expected,
+                "Browser Catalog",
+                message,
             )
 
     @keyword(tags=("Setter", "BrowserControl"))
