@@ -13,6 +13,7 @@
 # limitations under the License.
 
 # flake8: noqa
+
 from .data_types import (
     AssertionOperator,
     AutoClosingLevel,
@@ -20,17 +21,28 @@ from .data_types import (
     CookieSameSite,
     CookieType,
     ElementState,
+    GeoLocation,
+    HttpCredentials,
+    Proxy,
     RequestMethod,
     SelectAttribute,
     SelectionType,
     SupportedBrowsers,
     ViewportDimensions,
+    convert_typed_dict,
 )
+from .deprecated import attribute_warning
 from .js_utilities import (
     exec_scroll_function,
     get_abs_scroll_coordinates,
     get_rel_scroll_coordinates,
 )
 from .meta_python import find_by_id, locals_to_params
-from .misc import find_free_port, get_normalized_keyword, is_same_keyword
+from .misc import (
+    find_free_port,
+    get_normalized_keyword,
+    get_variable_value,
+    is_same_keyword,
+    keyword,
+)
 from .robot_booleans import is_falsy, is_truthy
